@@ -30,7 +30,7 @@ test_that("Parsing yrf format", {
   expect_equal(description(v),c("a looong description here","a looong description here\n"))
   expect_true(all(created(v)-now < 10))
   expect_warning(validator(.file="yamltests/invalid.yaml"))
-  expect_warning(validator(.file="yamltests/invalidR.yaml"))
+  out <- capture.output(expect_warning(validator(.file="yamltests/invalidR.yaml")))
 })
 
 test_that("Parsing options",{
